Struct parquet::data_type::Int96Type [−][src]
pub struct Int96Type {}Trait Implementations
impl DataType for Int96Type[src]
impl DataType for Int96Typetype T = Int96
fn get_physical_type() -> Type[src]
fn get_physical_type() -> TypeReturns Parquet physical type.
fn get_type_size() -> usize[src]
fn get_type_size() -> usizeReturns size in bytes for Rust representation of the physical type.
impl Encoder<Int96Type> for PlainEncoder<Int96Type>[src]
impl Encoder<Int96Type> for PlainEncoder<Int96Type>fn put(&mut self, values: &[Int96]) -> Result<()>[src]
fn put(&mut self, values: &[Int96]) -> Result<()>Encodes data from values.
fn encoding(&self) -> Encoding[src]
fn encoding(&self) -> EncodingReturns the encoding type of this encoder.
fn flush_buffer(&mut self) -> Result<ByteBufferPtr>[src]
fn flush_buffer(&mut self) -> Result<ByteBufferPtr>Flushes the underlying byte buffer that's being processed by this encoder, and return the immutable copy of it. This will also reset the internal state. Read more
impl Decoder<Int96Type> for PlainDecoder<Int96Type>[src]
impl Decoder<Int96Type> for PlainDecoder<Int96Type>fn get(&mut self, buffer: &mut [Int96]) -> Result<usize>[src]
fn get(&mut self, buffer: &mut [Int96]) -> Result<usize>Consumes values from this decoder and write the results to buffer. This will try to fill up buffer. Read more
fn set_data(&mut self, data: ByteBufferPtr, num_values: usize) -> Result<()>[src]
fn set_data(&mut self, data: ByteBufferPtr, num_values: usize) -> Result<()>Sets the data to decode to be data, which should contain num_values of values to decode. Read more
fn values_left(&self) -> usize[src]
fn values_left(&self) -> usizeReturns the number of values left in this decoder stream.
fn encoding(&self) -> Encoding[src]
fn encoding(&self) -> EncodingReturns the encoding for this decoder.