Trait parquet::data_type::DataType [−][src]
pub trait DataType {
type T: PartialEq + Debug + Default + Clone + Rand + AsBytes;
fn get_physical_type() -> Type;
fn get_type_size() -> usize;
}Contains the Parquet physical type information as well as the Rust primitive type presentation.
Associated Types
Required Methods
fn get_physical_type() -> Type
Returns Parquet physical type.
fn get_type_size() -> usize
Returns size in bytes for Rust representation of the physical type.
Implementors
impl DataType for BoolType type T = bool;impl DataType for Int32Type type T = i32;impl DataType for Int64Type type T = i64;impl DataType for Int96Type type T = Int96;impl DataType for FloatType type T = f32;impl DataType for DoubleType type T = f64;impl DataType for ByteArrayType type T = ByteArray;impl DataType for FixedLenByteArrayType type T = ByteArray;